pub fn register_transform_with_detection_and_context<C>(
custom: C,
) -> (&'static mut C, Transform)Expand description
Registers a custom transform with both detection and context capabilities.
pub fn register_transform_with_detection_and_context<C>(
custom: C,
) -> (&'static mut C, Transform)Registers a custom transform with both detection and context capabilities.